@@ -1,19 +1,20 @@
 from starlette.authentication import AuthCredentials, BaseUser
-from typing import Optional, Sequence
-from maleo.soma.schemas.token import AuthenticationToken
+from typing import Optional
+from maleo.soma.schemas.token import GeneralAuthenticationToken
+from maleo.soma.types.base import OptionalSequenceOfStrings
 
 
 class Credentials(AuthCredentials):
     def __init__(
         self,
-        token: Optional[AuthenticationToken] = None,
-        scopes: Optional[Sequence[str]] = None,
+        token: Optional[GeneralAuthenticationToken] = None,
+        scopes: OptionalSequenceOfStrings = None,
     ) -> None:
         self._token = token
         super().__init__(scopes)
 
     @property
-    def token(self) -> Optional[AuthenticationToken]:
+    def token(self) -> Optional[GeneralAuthenticationToken]:
         return self._token
 
 
