@@ -25,21 +25,21 @@ DEFAULT_ALLOW_METHODS: SequenceOfStrings = (
     "OPTIONS",
 )
 DEFAULT_ALLOW_HEADERS: SequenceOfStrings = (
-    "Authorization",
-    "Content-Type",
-    "X-Operation-Id",
-    "X-Request-Id",
-    "X-Requested-At",
-    "X-Signature",
+    "authorization",
+    "content-type",
+    "x-operation-id",
+    "x-request-id",
+    "x-requested-at",
+    "x-signature",
 )
 DEFAULT_EXPOSE_HEADERS: SequenceOfStrings = (
-    "X-New-Authorization",
-    "X-Operation-Id",
-    "X-Process-Time",
-    "X-Request-Id",
-    "X-Requested-At",
-    "X-Responded-At",
-    "X-Signature",
+    "x-new-authorization",
+    "x-operation-id",
+    "x-process-time",
+    "x-request-id",
+    "x-requested-at",
+    "x-responded-at",
+    "x-signature",
 )
 
 # Status
