@@ -1,4 +1,5 @@
 from pydantic import BaseModel, ConfigDict, Field
+from typing import Optional, TypeVar
 from maleo.soma.types.controller import OptionalMessageController
 
 
@@ -14,3 +15,8 @@ class ExtendedSubscriptionConfigurationDTO(SubscriptionConfigurationDTO):
     controller: OptionalMessageController = Field(
         None, description="Optional message controller"
     )
+
+
+SubscriptionsConfigurationT = TypeVar(
+    "SubscriptionsConfigurationT", bound=Optional[BaseModel]
+)
