@@ -3,16 +3,21 @@ from pydantic_settings import BaseSettings
 from pydantic import Field, model_validator
 from typing import Self
 from maleo.soma.enums.environment import Environment
+from maleo.soma.enums.execution import ApplicationExecution
 from maleo.soma.enums.service import ServiceKey, ServiceName
 from maleo.soma.schemas.service import ServiceContext
 from maleo.soma.types.base import OptionalString
 
 
 class Settings(BaseSettings):
+    EXECUTION: ApplicationExecution = Field(
+        ApplicationExecution.CONTAINER, description="Application's execution mode"
+    )
     ENVIRONMENT: Environment = Field(..., description="Environment")
     HOST: str = Field("127.0.0.1", description="Application's host")
     PORT: int = Field(8000, description="Application's port")
     HOST_PORT: int = Field(8000, description="Host's port")
+    DOCKER_NETWORK: str = Field("maleo-suite", description="Docker's network")
     SERVICE_KEY: ServiceKey = Field(..., description="Service's key")
     SERVICE_NAME: ServiceName = Field(..., description="Service's name")
     ROOT_PATH: str = Field("", description="Application's root path")
