@@ -15,7 +15,7 @@ from maleo.soma.enums.operation import (
 from maleo.soma.enums.secret import SecretFormat
 from maleo.soma.exceptions import NotFound, InternalServerError
 from maleo.soma.mappings.secret import FORMAT_TYPE_MAPPING
-from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
+from maleo.soma.schemas.authentication import GenericAuthentication
 from maleo.soma.schemas.data import DataPair
 from maleo.soma.schemas.operation.system import SystemOperationActionSchema
 from maleo.soma.schemas.operation.context import (
@@ -84,7 +84,7 @@ class GoogleSecretManager(GoogleClientManager):
             credentials=self._credentials
         )
         completed_at = datetime.now(tz=timezone.utc)
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
@@ -111,7 +111,7 @@ class GoogleSecretManager(GoogleClientManager):
         value: bytes,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> CreateSingleResourceOperationResult[SecretDataSchema[bytes], None]: ...
     @overload
     def create(
@@ -120,7 +120,7 @@ class GoogleSecretManager(GoogleClientManager):
         value: str,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> CreateSingleResourceOperationResult[SecretDataSchema[str], None]: ...
     def create(
         self,
@@ -128,7 +128,7 @@ class GoogleSecretManager(GoogleClientManager):
         value: Union[bytes, str],
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> CreateSingleResourceOperationResult[SecretDataSchema[Any], None]:
         if not isinstance(value, (bytes, str)):
             raise TypeError("Value type can only either be 'bytes' or 'str'")
@@ -165,7 +165,7 @@ class GoogleSecretManager(GoogleClientManager):
                 self._client.create_secret(request=request)
             except Exception as e:
                 completed_at = datetime.now(tz=timezone.utc)
-                raise InternalServerError(
+                raise InternalServerError[Optional[GenericAuthentication]](
                     service_context=self._service_context,
                     operation_id=operation_id,
                     operation_context=self._operation_context,
@@ -200,7 +200,9 @@ class GoogleSecretManager(GoogleClientManager):
             result = CreateSingleResourceOperationResult[
                 SecretDataSchema[value_type], None
             ](data=data, metadata=None, other=None)
-            CreateSingleResourceOperationSchema[SecretDataSchema[value_type], None](
+            CreateSingleResourceOperationSchema[
+                Optional[GenericAuthentication], SecretDataSchema[value_type], None
+            ](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -215,11 +217,13 @@ class GoogleSecretManager(GoogleClientManager):
                 action=operation_action,
                 resource=resource,
                 result=result,
-            ).log(self._logger, level=LogLevel.INFO)
+            ).log(
+                self._logger, level=LogLevel.INFO
+            )
             return result
         except Exception as e:
             completed_at = datetime.now(tz=timezone.utc)
-            raise InternalServerError(
+            raise InternalServerError[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
@@ -244,7 +248,7 @@ class GoogleSecretManager(GoogleClientManager):
         version: str = "latest",
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> ReadSingleResourceOperationResult[SecretDataSchema[bytes], None]: ...
 
     @overload
@@ -255,7 +259,7 @@ class GoogleSecretManager(GoogleClientManager):
         version: str = "latest",
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> ReadSingleResourceOperationResult[SecretDataSchema[str], None]: ...
 
     def read(
@@ -265,7 +269,7 @@ class GoogleSecretManager(GoogleClientManager):
         version: str = "latest",
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> ReadSingleResourceOperationResult[SecretDataSchema[Any], None]:
         operation_id = operation_id if operation_id is not None else uuid4()
         operation_action = ReadResourceOperationAction()
@@ -292,7 +296,7 @@ class GoogleSecretManager(GoogleClientManager):
             self._client.get_secret(request=request)
         except GoogleNotFound as gnf:
             completed_at = datetime.now(tz=timezone.utc)
-            raise NotFound(
+            raise NotFound[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
@@ -310,7 +314,7 @@ class GoogleSecretManager(GoogleClientManager):
             ) from gnf
         except Exception as e:
             completed_at = datetime.now(tz=timezone.utc)
-            raise InternalServerError(
+            raise InternalServerError[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
@@ -334,7 +338,7 @@ class GoogleSecretManager(GoogleClientManager):
             self._client.get_secret_version(request=request)
         except GoogleNotFound as gnf:
             completed_at = datetime.now(tz=timezone.utc)
-            raise NotFound(
+            raise NotFound[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
@@ -388,7 +392,9 @@ class GoogleSecretManager(GoogleClientManager):
             result = ReadSingleResourceOperationResult[
                 SecretDataSchema[value_type], None
             ](data=data, metadata=None, other=None)
-            ReadSingleResourceOperationSchema[SecretDataSchema[value_type], None](
+            ReadSingleResourceOperationSchema[
+                Optional[GenericAuthentication], SecretDataSchema[value_type], None
+            ](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -403,11 +409,13 @@ class GoogleSecretManager(GoogleClientManager):
                 action=operation_action,
                 resource=resource,
                 result=result,
-            ).log(self._logger, level=LogLevel.INFO)
+            ).log(
+                self._logger, level=LogLevel.INFO
+            )
             return result
         except Exception as e:
             completed_at = datetime.now(tz=timezone.utc)
-            raise InternalServerError(
+            raise InternalServerError[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
