@@ -15,7 +15,7 @@ from maleo.soma.enums.operation import (
     ResourceOperationCreateType,
 )
 from maleo.soma.exceptions import NotFound, InternalServerError
-from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
+from maleo.soma.schemas.authentication import GenericAuthentication
 from maleo.soma.schemas.data import DataPair
 from maleo.soma.schemas.data.google.storage import StorageDataSchema
 from maleo.soma.schemas.operation.system import (
@@ -123,7 +123,7 @@ class GoogleCloudStorage(GoogleClientManager):
         self._root_location = self._service_context.key
 
         completed_at = datetime.now(tz=timezone.utc)
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
@@ -169,7 +169,7 @@ class GoogleCloudStorage(GoogleClientManager):
         if self._client is not None:
             self._client.close()
 
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
@@ -196,7 +196,7 @@ class GoogleCloudStorage(GoogleClientManager):
         expiration: Expiration = Expiration.EXP_15MN,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> CreateSingleResourceOperationResult[StorageDataSchema, None]:
         operation_id = operation_id if operation_id is not None else uuid4()
         operation_action = CreateResourceOperationAction(
@@ -255,7 +255,9 @@ class GoogleCloudStorage(GoogleClientManager):
             result = CreateSingleResourceOperationResult[StorageDataSchema, None](
                 data=data, metadata=None, other=None
             )
-            CreateSingleResourceOperationSchema[StorageDataSchema, None](
+            CreateSingleResourceOperationSchema[
+                Optional[GenericAuthentication], StorageDataSchema, None
+            ](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -270,7 +272,9 @@ class GoogleCloudStorage(GoogleClientManager):
                 action=operation_action,
                 resource=resource,
                 result=result,
-            ).log(self._logger, level=LogLevel.INFO)
+            ).log(
+                self._logger, level=LogLevel.INFO
+            )
             return result
         except Exception as e:
             completed_at = datetime.now(tz=timezone.utc)
@@ -299,7 +303,7 @@ class GoogleCloudStorage(GoogleClientManager):
         expiration: Expiration = Expiration.EXP_15MN,
         operation_id: OptionalUUID = None,
         request_context: Optional[RequestContext] = None,
-        authentication: Optional[Union[Authentication, MandatoryAuthentication]] = None,
+        authentication: Optional[GenericAuthentication] = None,
     ) -> ReadSingleResourceOperationResult[StorageDataSchema, None]:
         operation_id = operation_id if operation_id is not None else uuid4()
         operation_action = ReadResourceOperationAction()
@@ -337,7 +341,9 @@ class GoogleCloudStorage(GoogleClientManager):
                 result = ReadSingleResourceOperationResult[StorageDataSchema, None](
                     data=data, metadata=None, other=None
                 )
-                ReadSingleResourceOperationSchema[StorageDataSchema, None](
+                ReadSingleResourceOperationSchema[
+                    Optional[GenericAuthentication], StorageDataSchema, None
+                ](
                     service_context=self._service_context,
                     id=operation_id,
                     summary=f"Successfully generated presigned url for file '{location}'",
@@ -352,7 +358,9 @@ class GoogleCloudStorage(GoogleClientManager):
                     authentication=authentication,
                     resource=resource,
                     result=result,
-                ).log(self._logger, level=LogLevel.INFO)
+                ).log(
+                    self._logger, level=LogLevel.INFO
+                )
                 return result
 
         blob = self.bucket.blob(blob_name=blob_name)
@@ -393,7 +401,9 @@ class GoogleCloudStorage(GoogleClientManager):
         result = ReadSingleResourceOperationResult[StorageDataSchema, None](
             data=data, metadata=None, other=None
         )
-        ReadSingleResourceOperationSchema[StorageDataSchema, None](
+        ReadSingleResourceOperationSchema[
+            Optional[GenericAuthentication], StorageDataSchema, None
+        ](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
@@ -408,5 +418,7 @@ class GoogleCloudStorage(GoogleClientManager):
             action=operation_action,
             resource=resource,
             result=result,
-        ).log(self._logger, level=LogLevel.INFO)
+        ).log(
+            self._logger, level=LogLevel.INFO
+        )
         return result
