@@ -1,5 +1,4 @@
 from functools import cached_property
-from typing import Literal, Sequence
 from Crypto.PublicKey.RSA import RsaKey
 from google.oauth2.service_account import Credentials
 from maleo.soma.dtos.credential import CredentialDTO, MaleoCredentialDTO
@@ -8,16 +7,15 @@ from maleo.soma.enums.secret import SecretFormat
 from maleo.soma.enums.token import TokenType
 from maleo.soma.managers.client.google.secret import GoogleSecretManager
 from maleo.soma.schemas.authentication import (
-    Authentication,
-    MandatoryAuthentication,
-    Credentials as RequestCredentials,
-    User,
+    PrivilegedCredentials,
+    AuthenticatedUser,
+    PrivilegedAuthentication,
 )
 from maleo.soma.schemas.token import (
-    AuthenticationToken,
-    CredentialPayload,
+    PrivilegedCredentialPayload,
     TimestampPayload,
-    Payload,
+    PrivilegedPayload,
+    PrivilegedAuthenticationToken,
 )
 from maleo.soma.types.base import OptionalString, OptionalUUID
 from maleo.soma.utils.loaders.yaml import from_string
@@ -60,11 +58,11 @@ class CredentialManager:
         )
 
     @cached_property
-    def token_credential_payload(self) -> CredentialPayload:
-        return CredentialPayload(
+    def token_credential_payload(self) -> PrivilegedCredentialPayload:
+        return PrivilegedCredentialPayload(
             iss=None,
             sub=str(self.maleo_credentials.id),
-            sr="administrator",
+            sr=["administrator"],
             u_i=self.maleo_credentials.id,
             u_uu=self.maleo_credentials.uuid,
             u_u=self.maleo_credentials.username,
@@ -88,14 +86,14 @@ class CredentialManager:
     @property
     def request_credentials(
         self,
-    ) -> RequestCredentials[AuthenticationToken, Sequence[str]]:
-        return RequestCredentials[AuthenticationToken, Sequence[str]](
-            token=AuthenticationToken(
+    ) -> PrivilegedCredentials:
+        return PrivilegedCredentials(
+            token=PrivilegedAuthenticationToken(
                 type=TokenType.ACCESS,
-                payload=Payload.model_validate(
+                payload=PrivilegedPayload.model_validate(
                     {
                         **self.token_credential_payload.model_dump(),
-                        **TimestampPayload.new().model_dump(),
+                        **TimestampPayload.new_timestamp().model_dump(),
                     }
                 ),
             ),
@@ -103,19 +101,14 @@ class CredentialManager:
         )
 
     @cached_property
-    def request_user(self) -> User[Literal[True]]:
-        return User[Literal[True]](
-            is_authenticated=True,
+    def request_user(self) -> AuthenticatedUser:
+        return AuthenticatedUser(
             display_name=self.maleo_credentials.username,
             identity=self.maleo_credentials.email,
         )
 
     @property
-    def mandatory_authentication(self) -> MandatoryAuthentication:
-        return MandatoryAuthentication(
+    def authentication(self) -> PrivilegedAuthentication:
+        return PrivilegedAuthentication(
             credentials=self.request_credentials, user=self.request_user
         )
-
-    @property
-    def authentication(self) -> Authentication:
-        return self.mandatory_authentication.to_authentication()
