@@ -2,7 +2,6 @@ import os
 from contextlib import contextmanager
 from datetime import datetime, timezone
 from pydantic import ValidationError
-from typing import Union
 from uuid import UUID
 from sqlalchemy import MetaData, text
 from sqlalchemy.engine import Engine, create_engine
@@ -24,7 +23,7 @@ from maleo.soma.exceptions import (
     DatabaseError,
 )
 from maleo.soma.models.table import BaseTable
-from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
+from maleo.soma.schemas.authentication import GenericAuthentication
 from maleo.soma.schemas.operation.context import generate_operation_context
 from maleo.soma.schemas.operation.system import (
     SuccessfulSystemOperationSchema,
@@ -71,7 +70,7 @@ class SessionManager:
                 bind=engine, expire_on_commit=False
             )
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema[None](
+            SuccessfulSystemOperationSchema[None, None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=operation_context,
@@ -88,7 +87,7 @@ class SessionManager:
             ).log(logger=self._logger, level=LogLevel.INFO)
         except Exception as e:
             completed_at = datetime.now(tz=timezone.utc)
-            error = InternalServerError(
+            error = InternalServerError[None](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=operation_context,
@@ -111,7 +110,7 @@ class SessionManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Union[Authentication, MandatoryAuthentication],
+        authentication: Optional[GenericAuthentication],
     ) -> Generator[Session, None, None]:
         """Reusable function for managing database sessions."""
         operation_context = generate_operation_context(
@@ -124,7 +123,7 @@ class SessionManager:
         )
         executed_at = datetime.now(tz=timezone.utc)
         session = self._sessionmaker()
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[Optional[GenericAuthentication], None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -143,7 +142,7 @@ class SessionManager:
         except SQLAlchemyError as se:
             session.rollback()  # Rollback on error
             completed_at = datetime.now(tz=timezone.utc)
-            error = DatabaseError(
+            error = DatabaseError[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=operation_context,
@@ -163,7 +162,7 @@ class SessionManager:
         except ValidationError as ve:
             session.rollback()  # Rollback on error
             completed_at = datetime.now(tz=timezone.utc)
-            error = UnprocessableEntity(
+            error = UnprocessableEntity[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=operation_context,
@@ -185,7 +184,7 @@ class SessionManager:
         except Exception as e:
             session.rollback()  # Rollback on error
             completed_at = datetime.now(tz=timezone.utc)
-            error = InternalServerError(
+            error = InternalServerError[Optional[GenericAuthentication]](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=operation_context,
@@ -205,7 +204,7 @@ class SessionManager:
         finally:
             session.close()  # Ensure session closes
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema[None](
+            SuccessfulSystemOperationSchema[Optional[GenericAuthentication], None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=operation_context,
@@ -225,7 +224,7 @@ class SessionManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Union[Authentication, MandatoryAuthentication],
+        authentication: Optional[GenericAuthentication],
     ) -> Generator[Session, None, None]:
         """Returns a generator that yields a SQLAlchemy session for dependency injection."""
         return self._session_handler(
@@ -239,7 +238,7 @@ class SessionManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Union[Authentication, MandatoryAuthentication],
+        authentication: Optional[GenericAuthentication],
     ) -> Generator[Session, None, None]:
         """Context manager for manual session handling. Supports `with SessionManager.get() as session:`"""
         yield from self._session_handler(
@@ -265,7 +264,7 @@ class SessionManager:
         if self._sessionmaker is not None:
             self._sessionmaker.close_all()
 
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -322,7 +321,7 @@ class DatabaseManager:
             )
 
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema[None](
+            SuccessfulSystemOperationSchema[None, None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -339,7 +338,7 @@ class DatabaseManager:
             ).log(logger=self._logger, level=LogLevel.INFO)
         except Exception as e:
             completed_at = datetime.now(tz=timezone.utc)
-            error = InternalServerError(
+            error = InternalServerError[None](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
@@ -364,7 +363,7 @@ class DatabaseManager:
         try:
             self._metadata.create_all(bind=self._engine)
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema[None](
+            SuccessfulSystemOperationSchema[None, None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -381,7 +380,7 @@ class DatabaseManager:
             ).log(logger=self._logger, level=LogLevel.INFO)
         except Exception as e:
             completed_at = datetime.now(tz=timezone.utc)
-            error = InternalServerError(
+            error = InternalServerError[None](
                 service_context=self._service_context,
                 operation_id=operation_id,
                 operation_context=self._operation_context,
@@ -408,7 +407,7 @@ class DatabaseManager:
         )
 
         completed_at = datetime.now(tz=timezone.utc)
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
@@ -440,7 +439,7 @@ class DatabaseManager:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Union[Authentication, MandatoryAuthentication],
+        authentication: Optional[GenericAuthentication],  # type: ignore
     ) -> bool:
         """Check database connectivity by executing a simple query."""
         operation_action = SystemOperationActionSchema(
@@ -455,7 +454,7 @@ class DatabaseManager:
             ) as session:
                 session.execute(text("SELECT 1"))
             completed_at = datetime.now(tz=timezone.utc)
-            SuccessfulSystemOperationSchema[None](
+            SuccessfulSystemOperationSchema[Optional[GenericAuthentication], None](
                 service_context=self._service_context,
                 id=operation_id,
                 context=self._operation_context,
@@ -488,7 +487,7 @@ class DatabaseManager:
         if self._engine is not None:
             self._engine.dispose()
 
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=self._operation_context,
