@@ -89,7 +89,7 @@ class MiddlewareManager:
         )
 
         completed_at = datetime.now(tz=timezone.utc)
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -142,7 +142,7 @@ class MiddlewareManager:
         add_cors_middleware(self._app, configuration=self._configuration.cors)
 
         completed_at = datetime.now(tz=timezone.utc)
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
