@@ -19,7 +19,7 @@ from maleo.soma.enums.operation import (
     SystemOperationType,
 )
 from maleo.soma.exceptions import TooManyRequests, InternalServerError
-from maleo.soma.schemas.authentication import Authentication
+from maleo.soma.schemas.authentication import OptionalAuthentication
 from maleo.soma.schemas.operation.context import generate_operation_context
 from maleo.soma.schemas.operation.resource.action import (
     extract_resource_operation_action,
@@ -95,7 +95,7 @@ class BaseMiddleware(BaseHTTPMiddleware):
             },
         )
 
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -123,7 +123,7 @@ class BaseMiddleware(BaseHTTPMiddleware):
             request_context = RequestContext.from_request(request=request)
 
             # Get Authentication
-            authentication = Authentication.from_request(request=request)
+            authentication = OptionalAuthentication.from_request(request=request)
 
             # Get Operation action
             resource_operation_action = extract_resource_operation_action(
