@@ -1,8 +1,8 @@
-from typing import Dict, Tuple, Type, Union
+from typing import Dict, Tuple, Type
 from uuid import UUID
 from maleo.soma.enums.logging import LogLevel
 from maleo.soma.exceptions import Error
-from maleo.soma.schemas.authentication import Authentication, MandatoryAuthentication
+from maleo.soma.schemas.authentication import OptionalAuthentication
 from maleo.soma.schemas.operation.context import OperationContextSchema
 from maleo.soma.schemas.operation.request import (
     RequestOperationSchema,
@@ -55,7 +55,7 @@ class RequestOperationLogger:
         operation_context: OperationContextSchema,
         operation_timestamp: OperationTimestamp,
         request_context: RequestContext,
-        authentication: Union[Authentication, MandatoryAuthentication],
+        authentication: OptionalAuthentication,
         response_context: ResponseContext,
         resource_operation_action: ResourceOperationActionSchema,
         is_success: bool,
