@@ -78,7 +78,7 @@ class RateLimiter:
         self._cleanup_task: Optional[asyncio.Task] = None
         self._shutdown_event = asyncio.Event()
 
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -238,7 +238,7 @@ class RateLimiter:
                     self._last_seen.pop(key, None)
 
                 completed_at = datetime.now(tz=timezone.utc)
-                SuccessfulSystemOperationSchema[None](
+                SuccessfulSystemOperationSchema[None, None](
                     service_context=self._service_context,
                     id=operation_id,
                     context=operation_context,
