@@ -11,14 +11,14 @@ from maleo.soma.enums.operation import (
     OperationTarget,
 )
 from maleo.soma.enums.token import TokenType
-from maleo.soma.schemas.authentication import Authentication
+from maleo.soma.schemas.authentication import OptionalAuthentication
 from maleo.soma.schemas.operation.context import generate_operation_context
 from maleo.soma.schemas.operation.system import (
     SuccessfulSystemOperationSchema,
 )
 from maleo.soma.schemas.operation.system.action import SystemOperationActionSchema
 from maleo.soma.schemas.operation.timestamp import OperationTimestamp
-from maleo.soma.schemas.token import CredentialPayload
+from maleo.soma.schemas.token import GeneralCredentialPayload
 from maleo.soma.schemas.request import RequestContext
 from maleo.soma.schemas.service import ServiceContext
 from maleo.soma.types.base import OptionalUUID
@@ -71,7 +71,7 @@ class ResponseBuilder:
             },
         )
 
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
@@ -90,7 +90,7 @@ class ResponseBuilder:
     def _should_regenerate_auth(
         self,
         request_context: RequestContext,
-        authentication: Authentication,
+        authentication: OptionalAuthentication,
         response: Response,
     ) -> bool:
         if authentication.credentials.token is not None:
@@ -107,7 +107,7 @@ class ResponseBuilder:
     def _add_new_authorization_header(
         self,
         request_context: RequestContext,
-        authentication: Authentication,
+        authentication: OptionalAuthentication,
         response: Response,
     ) -> Response:
         if authentication.credentials.token is None:
@@ -120,7 +120,7 @@ class ResponseBuilder:
         ):
             return response
 
-        credential = CredentialPayload(
+        credential = GeneralCredentialPayload(
             iss=authentication.credentials.token.payload.iss,
             sub=authentication.credentials.token.payload.sub,
             sr=authentication.credentials.token.payload.sr,
@@ -178,7 +178,7 @@ class ResponseBuilder:
         self,
         operation_id: UUID,
         request_context: RequestContext,
-        authentication: Authentication,
+        authentication: OptionalAuthentication,
         response: Response,
         responded_at: datetime,
         process_time: float,
