@@ -71,7 +71,7 @@ class StateMiddleware(BaseHTTPMiddleware):
             },
         )
 
-        SuccessfulSystemOperationSchema[None](
+        SuccessfulSystemOperationSchema[None, None](
             service_context=self._service_context,
             id=operation_id,
             context=operation_context,
