@@ -8,10 +8,7 @@ from maleo.soma.enums.operation import (
     ResourceOperationUpdateType,
 )
 from maleo.soma.mixins.general import SuccessT
-from maleo.soma.schemas.authentication import (
-    Authentication,
-    MandatoryAuthentication,
-)
+from maleo.soma.schemas.authentication import AuthenticationT
 from maleo.soma.schemas.data import DataT
 from maleo.soma.schemas.error import (
     ErrorSchema,
@@ -64,8 +61,8 @@ from .result import (
 class ResourceOperationSchema(
     AnyOperationResultMixin,
     ResourceMixin,
-    BaseOperationSchema[SuccessT, ResourceOperationActionSchemaT],
-    Generic[SuccessT, ResourceOperationActionSchemaT],
+    BaseOperationSchema[SuccessT, AuthenticationT, ResourceOperationActionSchemaT],
+    Generic[SuccessT, AuthenticationT, ResourceOperationActionSchemaT],
 ):
     type: OperationType = OperationType.RESOURCE
 
@@ -73,32 +70,38 @@ class ResourceOperationSchema(
 class FailedResourceOperationSchema(
     NoOperationResultMixin,
     ErrorMixin,
-    ResourceOperationSchema[Literal[False], ResourceOperationActionSchemaT],
-    Generic[ResourceOperationActionSchemaT],
+    ResourceOperationSchema[
+        Literal[False], AuthenticationT, ResourceOperationActionSchemaT
+    ],
+    Generic[AuthenticationT, ResourceOperationActionSchemaT],
 ):
     success: Literal[False] = False
 
 
 class CreateFailedResourceOperationSchema(
-    FailedResourceOperationSchema[CreateResourceOperationAction],
+    FailedResourceOperationSchema[AuthenticationT, CreateResourceOperationAction],
+    Generic[AuthenticationT],
 ):
     pass
 
 
 class ReadFailedResourceOperationSchema(
-    FailedResourceOperationSchema[ReadResourceOperationAction],
+    FailedResourceOperationSchema[AuthenticationT, ReadResourceOperationAction],
+    Generic[AuthenticationT],
 ):
     pass
 
 
 class UpdateFailedResourceOperationSchema(
-    FailedResourceOperationSchema[UpdateResourceOperationAction],
+    FailedResourceOperationSchema[AuthenticationT, UpdateResourceOperationAction],
+    Generic[AuthenticationT],
 ):
     pass
 
 
 class DeleteFailedResourceOperationSchema(
-    FailedResourceOperationSchema[DeleteResourceOperationAction],
+    FailedResourceOperationSchema[AuthenticationT, DeleteResourceOperationAction],
+    Generic[AuthenticationT],
 ):
     pass
 
@@ -114,9 +117,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> CreateFailedResourceOperationSchema: ...
+) -> CreateFailedResourceOperationSchema[AuthenticationT]: ...
 @overload
 def generate_failed_resource_operation(
     action: ReadResourceOperationAction,
@@ -128,9 +131,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> ReadFailedResourceOperationSchema: ...
+) -> ReadFailedResourceOperationSchema[AuthenticationT]: ...
 @overload
 def generate_failed_resource_operation(
     action: UpdateResourceOperationAction,
@@ -142,9 +145,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> UpdateFailedResourceOperationSchema: ...
+) -> UpdateFailedResourceOperationSchema[AuthenticationT]: ...
 @overload
 def generate_failed_resource_operation(
     action: DeleteResourceOperationAction,
@@ -156,9 +159,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> DeleteFailedResourceOperationSchema: ...
+) -> DeleteFailedResourceOperationSchema[AuthenticationT]: ...
 @overload
 def generate_failed_resource_operation(
     *,
@@ -171,9 +174,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> CreateFailedResourceOperationSchema: ...
+) -> CreateFailedResourceOperationSchema[AuthenticationT]: ...
 @overload
 def generate_failed_resource_operation(
     *,
@@ -185,9 +188,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> ReadFailedResourceOperationSchema: ...
+) -> ReadFailedResourceOperationSchema[AuthenticationT]: ...
 @overload
 def generate_failed_resource_operation(
     *,
@@ -201,9 +204,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> UpdateFailedResourceOperationSchema: ...
+) -> UpdateFailedResourceOperationSchema[AuthenticationT]: ...
 @overload
 def generate_failed_resource_operation(
     *,
@@ -215,9 +218,9 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
-) -> DeleteFailedResourceOperationSchema: ...
+) -> DeleteFailedResourceOperationSchema[AuthenticationT]: ...
 def generate_failed_resource_operation(
     action: Optional[AllResourceOperationAction] = None,
     *,
@@ -232,13 +235,13 @@ def generate_failed_resource_operation(
     summary: str,
     error: ErrorSchema,
     request_context: Optional[RequestContext],
-    authentication: Optional[Union[Authentication, MandatoryAuthentication]],
+    authentication: AuthenticationT,
     resource: Resource,
 ) -> Union[
-    CreateFailedResourceOperationSchema,
-    ReadFailedResourceOperationSchema,
-    UpdateFailedResourceOperationSchema,
-    DeleteFailedResourceOperationSchema,
+    CreateFailedResourceOperationSchema[AuthenticationT],
+    ReadFailedResourceOperationSchema[AuthenticationT],
+    UpdateFailedResourceOperationSchema[AuthenticationT],
+    DeleteFailedResourceOperationSchema[AuthenticationT],
 ]:
     if (action is None and type is None) or (action is not None and type is not None):
         raise ValueError("Only either 'action' or 'type' must be given")
@@ -256,7 +259,7 @@ def generate_failed_resource_operation(
             raise ValueError(f"Invalid 'action' type: '{type(action)}'")
 
         if isinstance(action, CreateResourceOperationAction):
-            return CreateFailedResourceOperationSchema(
+            return CreateFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -269,7 +272,7 @@ def generate_failed_resource_operation(
                 resource=resource,
             )
         elif isinstance(action, ReadResourceOperationAction):
-            return ReadFailedResourceOperationSchema(
+            return ReadFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -282,7 +285,7 @@ def generate_failed_resource_operation(
                 resource=resource,
             )
         elif isinstance(action, UpdateResourceOperationAction):
-            return UpdateFailedResourceOperationSchema(
+            return UpdateFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -295,7 +298,7 @@ def generate_failed_resource_operation(
                 resource=resource,
             )
         elif isinstance(action, DeleteResourceOperationAction):
-            return DeleteFailedResourceOperationSchema(
+            return DeleteFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -316,7 +319,7 @@ def generate_failed_resource_operation(
             action = generate_resource_operation_action(
                 type=type, create_type=create_type
             )
-            return CreateFailedResourceOperationSchema(
+            return CreateFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -330,7 +333,7 @@ def generate_failed_resource_operation(
             )
         elif type is ResourceOperationType.READ:
             action = generate_resource_operation_action(type=type)
-            return ReadFailedResourceOperationSchema(
+            return ReadFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -348,7 +351,7 @@ def generate_failed_resource_operation(
                 update_type=update_type,
                 status_update_type=status_update_type,
             )
-            return UpdateFailedResourceOperationSchema(
+            return UpdateFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -362,7 +365,7 @@ def generate_failed_resource_operation(
             )
         elif type is ResourceOperationType.DELETE:
             action = generate_resource_operation_action(type=type)
-            return DeleteFailedResourceOperationSchema(
+            return DeleteFailedResourceOperationSchema[AuthenticationT](
                 service_context=service_context,
                 id=id,
                 context=context,
@@ -383,8 +386,10 @@ def generate_failed_resource_operation(
 class SuccessfulResourceOperationSchema(
     OperationResultMixin[ResourceOperationResultSchema[MetadataT]],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], ResourceOperationActionSchemaT],
-    Generic[ResourceOperationActionSchemaT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, ResourceOperationActionSchemaT
+    ],
+    Generic[ResourceOperationActionSchemaT, AuthenticationT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -392,8 +397,10 @@ class SuccessfulResourceOperationSchema(
 class NoDataResourceOperationSchema(
     OperationResultMixin[NoDataResourceOperationResult[MetadataT]],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], ResourceOperationActionSchemaT],
-    Generic[ResourceOperationActionSchemaT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, ResourceOperationActionSchemaT
+    ],
+    Generic[ResourceOperationActionSchemaT, AuthenticationT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -401,8 +408,10 @@ class NoDataResourceOperationSchema(
 class CreateSingleResourceOperationSchema(
     OperationResultMixin[CreateSingleResourceOperationResult[DataT, MetadataT]],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], CreateResourceOperationAction],
-    Generic[DataT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, CreateResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -410,8 +419,10 @@ class CreateSingleResourceOperationSchema(
 class ReadSingleResourceOperationSchema(
     OperationResultMixin[ReadSingleResourceOperationResult[DataT, MetadataT]],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], ReadResourceOperationAction],
-    Generic[DataT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, ReadResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -419,8 +430,10 @@ class ReadSingleResourceOperationSchema(
 class UpdateSingleResourceOperationSchema(
     OperationResultMixin[UpdateSingleResourceOperationResult[DataT, MetadataT]],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], UpdateResourceOperationAction],
-    Generic[DataT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, UpdateResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -428,8 +441,10 @@ class UpdateSingleResourceOperationSchema(
 class DeleteSingleResourceOperationSchema(
     OperationResultMixin[DeleteSingleResourceOperationResult[DataT, MetadataT]],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], DeleteResourceOperationAction],
-    Generic[DataT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, DeleteResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -439,8 +454,10 @@ class CreateMultipleResourceOperationSchema(
         CreateMultipleResourceOperationResult[DataT, PaginationT, MetadataT]
     ],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], CreateResourceOperationAction],
-    Generic[DataT, PaginationT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, CreateResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, PaginationT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -450,8 +467,10 @@ class ReadMultipleResourceOperationSchema(
         ReadMultipleResourceOperationResult[DataT, PaginationT, MetadataT]
     ],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], ReadResourceOperationAction],
-    Generic[DataT, PaginationT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, ReadResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, PaginationT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -461,8 +480,10 @@ class UpdateMultipleResourceOperationSchema(
         UpdateMultipleResourceOperationResult[DataT, PaginationT, MetadataT]
     ],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], UpdateResourceOperationAction],
-    Generic[DataT, PaginationT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, UpdateResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, PaginationT, MetadataT],
 ):
     success: Literal[True] = True
 
@@ -472,7 +493,9 @@ class DeleteMultipleResourceOperationSchema(
         DeleteMultipleResourceOperationResult[DataT, PaginationT, MetadataT]
     ],
     NoErrorMixin,
-    ResourceOperationSchema[Literal[True], DeleteResourceOperationAction],
-    Generic[DataT, PaginationT, MetadataT],
+    ResourceOperationSchema[
+        Literal[True], AuthenticationT, DeleteResourceOperationAction
+    ],
+    Generic[AuthenticationT, DataT, PaginationT, MetadataT],
 ):
     success: Literal[True] = True
