@@ -1,6 +1,7 @@
 from typing import Generic, Literal
 from maleo.soma.mixins.general import SuccessT
 from maleo.soma.enums.operation import OperationType
+from maleo.soma.schemas.authentication import AuthenticationT
 from maleo.soma.schemas.error import (
     NoErrorMixin,
     ErrorMixin,
@@ -17,14 +18,17 @@ from .action import SystemOperationActionSchema
 
 class SystemOperationSchema(
     AnyOperationResultMixin,
-    BaseOperationSchema[SuccessT, SystemOperationActionSchema],
-    Generic[SuccessT],
+    BaseOperationSchema[SuccessT, AuthenticationT, SystemOperationActionSchema],
+    Generic[SuccessT, AuthenticationT],
 ):
     type: OperationType = OperationType.SYSTEM
 
 
 class FailedSystemOperationSchema(
-    NoOperationResultMixin, ErrorMixin, SystemOperationSchema[Literal[False]]
+    NoOperationResultMixin,
+    ErrorMixin,
+    SystemOperationSchema[Literal[False], AuthenticationT],
+    Generic[AuthenticationT],
 ):
     success: Literal[False] = False
 
@@ -32,7 +36,7 @@ class FailedSystemOperationSchema(
 class SuccessfulSystemOperationSchema(
     OptionalOperationResultMixin[OperationResultSchemaT],
     NoErrorMixin,
-    SystemOperationSchema[Literal[True]],
-    Generic[OperationResultSchemaT],
+    SystemOperationSchema[Literal[True], AuthenticationT],
+    Generic[AuthenticationT, OperationResultSchemaT],
 ):
     success: Literal[True] = True
