@@ -3,12 +3,12 @@ from dotenv import load_dotenv
 from pydantic import BaseModel, Field
 from typing import Optional
 from maleo.soma.enums.environment import Environment
-from maleo.soma.enums.service import Service
+from maleo.soma.enums.service import ServiceKey
 
 
 class ServiceContext(BaseModel):
     environment: Environment = Field(..., description="Service's environment")
-    key: Service = Field(..., description="Service's key")
+    key: ServiceKey = Field(..., description="Service's key")
 
     @classmethod
     def from_env(cls) -> "ServiceContext":
@@ -21,7 +21,7 @@ class ServiceContext(BaseModel):
         if key is None:
             raise ValueError("Variable 'SERVICE_KEY' not found in ENV")
 
-        return cls(environment=Environment(environment), key=Service(key))
+        return cls(environment=Environment(environment), key=ServiceKey(key))
 
 
 class ServiceContextMixin(BaseModel):
