@@ -1,13 +1,13 @@
 from Crypto.PublicKey.RSA import RsaKey
 from typing import Optional
-from maleo.soma.schemas.authentication import Authentication
+from maleo.soma.schemas.authentication import OptionalAuthentication
 from maleo.soma.schemas.authorization import Authorization
 from .token import reencode
 
 
 def validate_authentication_authorization(
     private_key: RsaKey,
-    authentication: Authentication,
+    authentication: OptionalAuthentication,
     authorization: Optional[Authorization] = None,
 ):
     if (
