@@ -12,15 +12,15 @@ def extract_operation_id(request: Request) -> UUID:
 
 def extract_client_ip(conn: HTTPConnection) -> str:
     """Extract client IP with more robust handling of proxies"""
-    # * Check for X-Forwarded-For header (common when behind proxy/load balancer)
-    x_forwarded_for = conn.headers.get("X-Forwarded-For")
+    # * Check for x-forwarded-for header (common when behind proxy/load balancer)
+    x_forwarded_for = conn.headers.get("x-forwarded-for")
     if x_forwarded_for:
         # * The client's IP is the first one in the list
         ips = [ip.strip() for ip in x_forwarded_for.split(",")]
         return ips[0]
 
-    # * Check for X-Real-IP header (used by some proxies)
-    x_real_ip = conn.headers.get("X-Real-IP")
+    # * Check for x-real-ip header (used by some proxies)
+    x_real_ip = conn.headers.get("x-real-ip")
     if x_real_ip:
         return x_real_ip
 
