@@ -17,8 +17,21 @@ from maleo.soma.utils.merger import merge_dicts
 
 
 class GoogleCloudLogging:
-    def __init__(self, credentials_path: Optional[Union[Path, str]] = None) -> None:
-        self._credentials = load(credentials_path=credentials_path)
+    def __init__(
+        self,
+        credentials: Optional[Credentials] = None,
+        credentials_path: Optional[Union[Path, str]] = None,
+    ) -> None:
+        if credentials is not None and credentials_path is not None:
+            raise ValueError(
+                "Only either 'credentials' or 'credentials_path' can be passed as parameter"
+            )
+
+        if credentials is not None:
+            self._credentials = credentials
+        else:
+            self._credentials = load(credentials_path)
+
         self._client = Client(credentials=self._credentials)
         self._client.setup_logging()
 
