@@ -5,25 +5,31 @@ from datetime import timedelta
 from typing import Union, overload
 from maleo.soma.enums.expiration import Expiration
 from maleo.soma.enums.key import RSAKeyType
-from maleo.soma.schemas.token import CredentialPayload, TimestampPayload, Payload
+from maleo.soma.schemas.token import (
+    GenericCredentialPayload,
+    TimestampPayload,
+    GenericPayload,
+    PayloadT,
+    GeneralPayload,
+)
 from maleo.soma.types.base import BytesOrString, OptionalDatetime, OptionalString
 from maleo.soma.utils.loaders.key.rsa import with_pycryptodome
 
 
 @overload
 def reencode(
-    payload: Payload,
+    payload: GenericPayload,
     key: RsaKey,
 ) -> str: ...
 @overload
 def reencode(
-    payload: Payload,
+    payload: GenericPayload,
     key: BytesOrString,
     *,
     password: OptionalString = None,
 ) -> str: ...
 def reencode(
-    payload: Payload,
+    payload: GenericPayload,
     key: Union[RsaKey, BytesOrString],
     *,
     password: OptionalString = None,
@@ -46,7 +52,7 @@ def reencode(
 
 @overload
 def encode(
-    credential: CredentialPayload,
+    credential: GenericCredentialPayload,
     key: RsaKey,
     *,
     iat_dt: OptionalDatetime = None,
@@ -54,7 +60,7 @@ def encode(
 ) -> str: ...
 @overload
 def encode(
-    credential: CredentialPayload,
+    credential: GenericCredentialPayload,
     key: BytesOrString,
     *,
     password: OptionalString = None,
@@ -62,16 +68,16 @@ def encode(
     exp_in: Expiration = Expiration.EXP_15MN,
 ) -> str: ...
 def encode(
-    credential: CredentialPayload,
+    credential: GenericCredentialPayload,
     key: Union[RsaKey, BytesOrString],
     *,
     password: OptionalString = None,
     iat_dt: OptionalDatetime = None,
     exp_in: Expiration = Expiration.EXP_15MN,
 ) -> str:
-    timestamp = TimestampPayload.new(iat_dt=iat_dt, exp_in=exp_in)
+    timestamp = TimestampPayload.new_timestamp(iat_dt=iat_dt, exp_in=exp_in)
 
-    payload = Payload.model_validate(
+    payload = GenericPayload.model_validate(
         {**credential.model_dump(), **timestamp.model_dump()}
     )
 
@@ -92,13 +98,15 @@ def encode(
 
 
 def decode(
+    payload_type: type[PayloadT] = GeneralPayload,
+    *,
     token: str,
     key: Union[RsaKey, BytesOrString],
     audience: str | Iterable[str] | None = None,
     subject: str | None = None,
     issuer: str | Sequence[str] | None = None,
     leeway: float | timedelta = 0,
-) -> Payload:
+) -> PayloadT:
     payload_dict = jwt.decode(
         jwt=token,
         key=key.export_key() if isinstance(key, RsaKey) else key,
@@ -109,6 +117,6 @@ def decode(
         leeway=leeway,
     )
 
-    payload = Payload.model_validate(payload_dict)
+    payload = payload_type.model_validate(payload_dict)
 
     return payload
